@@ -57,6 +57,10 @@ class PipeTestCase(TestCase):
         # https://docker-py.readthedocs.io/en/stable/containers.html#docker.models.containers.ContainerCollection.run
         cwd = os.getcwd()
 
+        working_dir = cwd
+        if kwargs.get('working_dir'):
+            working_dir = kwargs.pop('working_dir')
+
         volumes = {cwd: {'bind': cwd, 'mode': 'rw'}}
         if kwargs.get('volumes'):
             volumes.update(kwargs.pop('volumes'))
@@ -66,7 +70,7 @@ class PipeTestCase(TestCase):
                 self.image_tag,
                 command=cmd,
                 volumes=volumes,
-                working_dir=cwd,
+                working_dir=working_dir,
                 detach=True,
                 **kwargs
             )
